@@ -25,6 +25,17 @@ class PaddingMixin:
 
 
 class PrivateKey(BasePrivateKey, PaddingMixin):
+    """Provides asymmetric encryption.
+
+    Attributes
+    ----------
+    algorthm : str
+        Name of encryption algorithm.
+    key_sizes : iterable
+        Available sizes (in bits) for key.
+    default_size : int
+        Default key size in bits.
+    """
     algorithm = "RSA"
     encoding = serialization.Encoding.PEM
     format = serialization.PrivateFormat.PKCS8
@@ -32,6 +43,11 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
     default_size = 2048
 
     def __init__(self, private_key_object: rsa.RSAPrivateKey) -> None:
+        """
+        Parameters
+        ----------
+        private_key_object : cryptography.hazmat.primitives. ... .RSAPrivateKey
+        """
         self._private_key = private_key_object
 
     @property
@@ -51,7 +67,7 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
     @raises(exceptions.KeyGenerationError)
     def generate(cls: Type[PrivateKey],
                  key_size: Optional[int] = None) -> PrivateKey:
-        """Generate Public Key with set key size.
+        """Generate Private Key with set key size.
 
         Parameters
         ----------
@@ -61,6 +77,10 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
         Returns
         -------
         Private Key object.
+
+        Raises
+        ------
+        KeyGenerationError
         """
         if key_size and key_size not in cls.key_sizes:
             raise exceptions.KeyGenerationError(
@@ -73,6 +93,7 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
         return cls(private_key)
 
     @classmethod
+    @raises(exceptions.KeyLoadingError)
     def load(cls: Type[PrivateKey], serialized_key: bytes,
              password: Optional[bytes] = None) -> PrivateKey:
         """Load Private Key from PEM encoded serialized byte data.
@@ -87,15 +108,20 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
         Returns
         -------
         Private Key object.
+
+        Raises
+        ------
+        KeyLoadingError
         """
         private_key = serialization.load_pem_private_key(
             serialized_key,
             password
         )
         if not isinstance(private_key, rsa.RSAPrivateKey):
-            raise ValueError
+            raise exceptions.KeyLoadingError("Invalid key format.")
         return cls(private_key)
 
+    @raises(exceptions.KeySerializationError)
     def serialize(self, password: Optional[bytes] = None) -> bytes:
         """Serialize Private Key. Can be encrypted with password.
 
@@ -107,6 +133,10 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
         Returns
         -------
         PEM encoded serialized Private Key.
+
+        Raises
+        ------
+        KeySerializationError
         """
         if password:
             encryption_algorithm = serialization.BestAvailableEncryption(
@@ -121,36 +151,108 @@ class PrivateKey(BasePrivateKey, PaddingMixin):
 
     @raises(exceptions.EncryptionError)
     def encrypt(self, data: bytes) -> bytes:
-        """Encrypt byte data with Public Key generated for this Private Key."""
+        """Encrypt byte data with Public Key generated for this Private Key.
+
+        Parameters
+        ----------
+        data : bytes
+            Byte data to encrypt.
+
+        Returns
+        -------
+        Encrypted bytes.
+
+        Raises
+        ------
+        EncryptionError
+        """
         return self.public_key.encrypt(data)
 
     @raises(exceptions.DecryptionError)
     def decrypt(self, encrypted_data: bytes) -> bytes:
-        """Decrypt byte data."""
+        """Decrypt byte data.
+
+        Parameters
+        ----------
+        encrypted_data : bytes
+            Byte data to decrypt.
+
+        Returns
+        -------
+        Decrypted bytes.
+
+        Raises
+        ------
+        DecryptionError
+        """
         return self._private_key.decrypt(
             encrypted_data,
             padding=PrivateKey.encryption_padding
         )
 
+    @raises(exceptions.SingingError)
     def sign(self, data: bytes) -> bytes:
-        """Sign byte data."""
+        """Sign byte data.
+
+        Parameters
+        ----------
+        data : bytes
+            Byte data to sign.
+
+        Returns
+        -------
+        Singed byte data.
+
+        Raises
+        ------
+        SingingError
+        """
         return self._private_key.sign(
             data,
             padding=PrivateKey.signing_padding,
             algorithm=PrivateKey.signing_hash_algorithm
         )
 
+    @raises(exceptions.VerificationError)
     def verify(self, signature: bytes, data: bytes) -> bool:
-        """Verify signature with Public Key generated for this Private Key."""
+        """Verify signature with Public Key generated for this Private Key.
+
+        Parameters
+        ----------
+        signature : bytes
+            Signed byte data.
+        data : bytes
+            Original byte data.
+
+        Returns
+        -------
+        True if signature matches, otherwise False.
+
+        Raises
+        ------
+        VerificationError
+        """
         return self.public_key.verify(signature, data)
 
 
 class PublicKey(BasePublicKey, PaddingMixin):
+    """Provides asymmetric encryption via public key.
+
+    Attributes
+    ----------
+    algorthm : str
+        Name of encryption algorithm.
+    """
     algorithm = PrivateKey.algorithm
     encoding = PrivateKey.encoding
     format = serialization.PublicFormat.SubjectPublicKeyInfo
 
     def __init__(self, public_key_object: rsa.RSAPublicKey) -> None:
+        """
+        Parameters
+        ----------
+        public_key_object : cryptography.hazmat.primitives. ... .RSAPublicKey
+        """
         self._public_key = public_key_object
 
     @property
@@ -159,6 +261,7 @@ class PublicKey(BasePublicKey, PaddingMixin):
         return self._public_key.key_size
 
     @classmethod
+    @raises(exceptions.KeyLoadingError)
     def load(cls: Type[PublicKey], serialized_key: bytes) -> PublicKey:
         """Load Public Key from PEM encoded serialized byte data.
 
@@ -170,37 +273,73 @@ class PublicKey(BasePublicKey, PaddingMixin):
         Returns
         -------
         Public Key object.
+
+        Raises
+        ------
+        KeyLoadingError
         """
         public_key = serialization.load_pem_public_key(serialized_key)
         if not isinstance(public_key, rsa.RSAPublicKey):
-            raise ValueError
+            raise exceptions.KeyLoadingError("Invalid key format.")
         return cls(public_key)
 
+    @raises(exceptions.KeySerializationError)
     def serialize(self) -> bytes:
         """Serialize Public Key.
 
         Returns
         -------
         PEM encoded serialized Public Key.
+
+        Raises
+        ------
+        KeySerializationError
         """
         return self._public_key.public_bytes(
             encoding=PublicKey.encoding,
             format=PublicKey.format
         )
 
+    @raises(exceptions.EncryptionError)
     def encrypt(self, data: bytes) -> bytes:
-        """Encrypt byte data using this Public Key."""
+        """Encrypt byte data using this Public Key.
+
+        Parameters
+        ----------
+        data : bytes
+            Byte data to encrypt.
+
+        Returns
+        -------
+        Encrypted bytes.
+
+        Raises
+        ------
+        EncryptionError
+        """
         return self._public_key.encrypt(
             data,
             padding=PublicKey.encryption_padding
         )
 
+    @raises(exceptions.VerificationError)
     def verify(self, signature: bytes, data: bytes) -> bool:
         """Verify signature data with this Public Key.
 
+        Parameters
+        ----------
+        signature : bytes
+            Signed byte data.
+        data : bytes
+            Original byte data.
+
         Returns
         -------
         True if signature matches, otherwise False.
+
+        Raises
+        ------
+        VerificationError
         """
         try:
             self._public_key.verify(
